.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install pydrill

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pydrill
    $ pip install pydrill

Latest version from git::

    $ pip install git+git://github.com/PythonicNinja/pydrill.git
